@@ -16,7 +16,7 @@ use Path::Tiny 'path';
 use Text::Diff ();
 use Try::Tiny qw( try catch finally );
 
-our $VERSION = '1.15'; # VERSION
+our $VERSION = '1.16'; # VERSION
 
 my $env;
 
@@ -411,7 +411,7 @@ sub update {
 
             my $type = $1;
 
-            if ( $type eq 'deploy' ) {
+            if ( $type and $type eq 'deploy' ) {
                 $self->revert($a);
                 $self->deploy($b);
             }
@@ -597,7 +597,7 @@ App::Dest - Deployment State Manager
 
 =head1 VERSION
 
-version 1.15
+version 1.16
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/dest.svg)](https://travis-ci.org/gryphonshafer/dest)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/dest/badge.png)](https://coveralls.io/r/gryphonshafer/dest)
@@ -635,10 +635,10 @@ dest COMMAND [DIR || NAME]
 
 =head1 DESCRIPTION
 
-dest is a simple "deployment state" change management tool. Inspired by
+C<dest> is a simple "deployment state" change management tool. Inspired by
 what Sqitch does for databases, it provides a simple mechanism for writing
 deploy, verify, and revert parts of a change action. The typical use of
-dest is in a development context because it allows for simplified state
+C<dest> is in a development context because it allows for simplified state
 changes when switching between branches (as an example).
 
 Let's say you're working with a group of other software engineers on a
@@ -649,11 +649,14 @@ installation of libraries or other applications. Then let's also say the team
 branches, works on stuff, shares those branches, reverts, merges, etc. And also
 from time to time you want to go back in time a bit so you can reproduce a bug.
 Maintaining the database state and the state of the system across all that
-activity can be problematic. dest tries to solve this in a very simple way,
+activity can be problematic. C<dest> tries to solve this in a very simple way,
 letting you be able to deploy, revert, and verify to any point in time in
 the development history.
 
-Note that using dest for production deployment, provisioning, or configuration
+See below for an example scenario that may help illustrate using C<dest> in a
+pseudo real world situation.
+
+Note that using C<dest> for production deployment, provisioning, or configuration
 management is not advised. Use a full-featured configuration management tool
 instead.
 
@@ -662,22 +665,23 @@ instead.
 =head1 COMMANDS
 
 Typing just C<dest> should bring up the usage instructions, which include a
-command list. In nearly all cases, dest assumes you are calling dest from
-the root directory of your project. If not, it will complain.
+command list. You should be able to execute C<dest> commands from any directory
+at or below your project's root directory once the project has been initiated
+in C<dest>.
 
 =head2 init
 
-To start using dest, you need to initialize your project by calling C<init>
+To start using C<dest>, you need to initialize your project by calling C<init>
 while in the root directory of your project. (If you are in a different
-directory, dest will assume that is your project's root directory.)
+directory, C<dest> will assume that is your project's root directory.)
 
 The initialization will result in a C<.dest> directory being created.
-You'll almost certainly want to add ".dest" to your `.gitignore` file or
+You'll almost certainly want to add ".dest" to your C<.gitignore> file or
 similar revision control ignore file.
 
 =head2 add DIR
 
-Once a project has been initialized, you need to tell dest what directories
+Once a project has been initialized, you need to tell C<dest> what directories
 you want to "track". Into these tracked directories you'll place subdirectories
 with recognizable names, and into each subdirectory a set of 3 files: deploy,
 revert, and verify.
@@ -693,7 +697,7 @@ the verify file let's you verify the deploy file worked.
 
 =head2 rm DIR
 
-This removes a directory from the dest tracking list.
+This removes a directory from the C<dest> tracking list.
 
 =head2 watches
 
@@ -755,7 +759,7 @@ says your state should be. For example, you might see something like this:
       M db/schema/deploy
     ok - etc
 
-dest will report for each tracked directory what are new changes that haven't
+C<dest> will report for each tracked directory what are new changes that haven't
 yet been deployed (marked with a "+"), features that have been deployed in your
 current system state but are missing from the code (marked with a "-"), and
 changes to previously existing files (marked with an "M").
@@ -772,9 +776,9 @@ action name, or specific sub-action.
 
 =head2 clean
 
-Let's say that for some reason you have a delta between what dest thinks your
+Let's say that for some reason you have a delta between what C<dest> thinks your
 system is and what your code says it ought to be, and you really believe your
-code is right. You can call C<clean> to tell dest to just assume that what
+code is right. You can call C<clean> to tell C<dest> to just assume that what
 the code says is right.
 
 =head2 preinstall
@@ -782,7 +786,7 @@ the code says is right.
 Let's say you're setting up a new system or installing the project/application,
 so you start by creating yourself a working directory. At some point, you'll
 want to deploy all the deploy actions. You'll need to C<init> and C<add> the
-directories/paths you need. But dest will have a cache that matches the
+directories/paths you need. But C<dest> will have a cache that matches the
 current working directory. At this point, you need to C<preinstall> to remove
 that cache and be in a state where you can C<update>.
 
@@ -796,7 +800,7 @@ Here's an example of what you might want:
 
 =head2 deploy NAME
 
-This tells dest to deploy a specific action. For example, if you called
+This tells C<dest> to deploy a specific action. For example, if you called
 C<status> and got back results like in the status example above, you might then
 want to:
 
@@ -812,12 +816,12 @@ provided, all actions under directories that are tracked.
 
 Unlike deploy and revert files, which can run the user through all sorts of
 user input/output, verify files must return some value that is either true
-or false. dest will assume that if it sees a true value, verification is
+or false. C<dest> will assume that if it sees a true value, verification is
 confirmed. If it receives a false value, verification is assumed to have failed.
 
 =head2 revert NAME
 
-This tells dest to revert a specific action. For example, if you deployed
+This tells C<dest> to revert a specific action. For example, if you deployed
 C<db/new_function> but then you wanted to revert it, you'd:
 
     dest revert db/new_function
@@ -852,11 +856,11 @@ to restrict the update to only operate within the directories you specify.
 This will not prevent cross-directory dependencies, however. For example, if
 you have two tracked directories and limit the update to only one directory and
 within the directory there is an action with a dependency on an action in the
-non-specificied directory, that action will be triggered.
+non-specified directory, that action will be triggered.
 
 =head2 version
 
-Displays the current dest version.
+Displays the current C<dest> version.
 
 =head2 help
 
@@ -864,7 +868,7 @@ Displays a synposis of commands and their usage.
 
 =head2 man
 
-Displays the man page for dest.
+Displays the man page for C<dest>.
 
 =head1 DEPENDENCIES
 
@@ -881,17 +885,17 @@ that adds a column, you might have:
 
 =head1 WRAPPERS
 
-Unless a "wrapper" is used (and thus, by default), dest will assume that the
+Unless a "wrapper" is used (and thus, by default), C<dest> will assume that the
 action files (those 3 files under each action name) are self-contained
 executable files. Often if not almost always the action sub-files would be a
 lot simpler and contain less code duplication if they were executed through
 some sort of wrapper.
 
 Given our database example, we'd likely want each of the action sub-files to be
-pure SQL. In that case, we'll need to write some wrapper program that dest
+pure SQL. In that case, we'll need to write some wrapper program that C<dest>
 will run that will then consume and run the SQL files as appropriate.
 
-dest looks for wrapper files up the chain from the location of the action file.
+C<dest> looks for wrapper files up the chain from the location of the action file.
 Specifically, it'll assume a file is a wrapper if the filename is "dest.wrap".
 If such a file is found, then that file is called, and the name of the action
 sub-file is passed as its only argument.
@@ -904,9 +908,7 @@ As an example, let's say I created an action set that looked like this
             revert
             verify
 
-Let's then also say that the C<example/ls/deploy> file contains:
-
-    ls
+Let's then also say that the C<example/ls/deploy> file contains: C<ls>
 
 I could create a deployment file C<example/dest.wrap> that looked like this:
 
@@ -915,29 +917,168 @@ I could create a deployment file C<example/dest.wrap> that looked like this:
 
 Wrappers will only ever be run from the current code. For example, if you have
 a revert file for some action and you checkout your working directory to a
-point in time prior to the revert file existing, dest maintains a copy of the
+point in time prior to the revert file existing, C<dest> maintains a copy of the
 original revert file so it can revert the action. However, it will always rely
 on whatever wrapper is in the current working directory.
 
 =head1 WATCH FILE
 
 Optionally, you can elect to use a watch file that can be committed to your
-favorite revision control system. In the root dirctory of your project, create
-a filed called "dest.watch" and list therein the directores (relative to the
+favorite revision control system. In the root directory of your project, create
+a filed called "dest.watch" and list therein the directories (relative to the
 root directory of the project) to watch.
 
-If this "dest.watch" file exists in the root directory of your project, dest
+If this "dest.watch" file exists in the root directory of your project, C<dest>
 will add the following behavior:
 
-During an "init" action, the dest.watch file will be read to setup all watched
+During an "init" action, the C<dest.watch> file will be read to setup all watched
 directories (as though you manually called the "add" action on each).
 
-During a "status" action, dest will report any differences between your current
-watch list and the dest.watch file.
+During a "status" action, C<dest> will report any differences between your current
+watch list and the C<dest.watch> file.
 
-During an "update" action, dest will automatically add (as if you manually
-called the "add" action) each directory in the dest.watch file that is
-currently not watched by dest prior to executing the update action.
+During an "update" action, C<dest> will automatically add (as if you manually
+called the "add" action) each directory in the C<dest.watch> file that is
+currently not watched by C<dest> prior to executing the update action.
+
+=head1 EXAMPLE SCENARIO
+
+To help illustrate what C<dest> can do, consider the following example scenario.
+You start a new project that requires the use of a typical database. You want
+to control the schema of that database with progressively executed SQL files.
+You also have data operations that require more functionality than what SQL can
+provide, so you'd like to have data operations handled by progressively executed
+Perl programs.
+
+=head2 Project Initiation
+
+You could setup your changes and C<dest> as follows (starting in your project's
+root directory):
+
+    mkdir db data     # create the directories
+    dest init         # initiate dest for your project
+    dest add db data  # add the directories to the dest watch list
+    dest writewatch   # write the watch list (so others can init without adding)
+    dest status       # show the current status (which is everything is OK)
+
+=head2 Create Schema Action
+
+The next step would probably be to create your database schema as a C<dest>
+action. Actions include deploy, verify, and revert files. You can use the "make"
+command to create these files for you. The command will return the list of files
+created, so you can wrap the command to your favorite editor.
+
+    dest make db/schema sql       # create "schema" action as ".sql" files
+    vi `dest list db/schema`      # list the "schema" files into vi
+    vi `dest make db/schema sql`  # the previous 2 commands as 1 command
+
+Your deploy file will be the SQL required to create your schema. The revert file
+reverts what the deploy file deploys. The verify file needs to return some
+positive value if and only if the deploy action worked.
+
+Since your local CLI shell probably doesn't know how to execute SQL files
+natively, you'll likely need to create a C<dest.wrap> file.
+
+    touch db/dest.wrap && chmod u+x db/dest.wrap && vi db/dest.wrap
+
+This file if it exists will get executed instead of the deploy, verify, and
+revert files, and it will be passed the action file being executed.
+
+=head2 Status and Deploying
+
+Now, check the project's C<dest> status:
+
+    dest s  # short for "dest status"
+
+You should see:
+
+    ok - data
+    diff - db
+      + db/schema
+
+This indicates that the "schema" action exists in your code but has not been
+executed on your environment. To execute, you have a couple options:
+
+    dest deploy db/schema  # explicitly deploy the "schema" action
+    dest update            # make dest do whatever status says needs to be done
+
+If you run C<dest update> and there's nothing to do, C<dest> will happily do
+nothing. If you run C<dest deploy db/schema> after having already deployed
+"schema", C<dest> will complain that "schema" has already been deployed. If you
+really, really want to run a deploy of "schema" again:
+
+    dest redeploy db/schema  # deploy "schema" even if you already did
+
+=head2 Changing a Deployed Action
+
+If you discover you made a mistake in a table definition inside your "schema"
+deploy action file, you could either create a second action to change that table
+or change the "schema" deploy and "revdeploy" to revert the old "schema" deploy
+action and deploy the new "schema" deploy action. Let's alter the deploy action
+already created, then check status.
+
+    vi db/schema/deploy.sql  # fix the table definition
+    dest status
+
+You should see something like:
+
+    ok - data
+    diff - db
+      db/schema/deploy.sql
+        M db/schema/deploy.sql
+
+This indicates that the C<schema/deploy> action is different than what was
+deployed. You can revert the action and deploy it with the "revert" and "deploy"
+actions, or do it in a single "revdeploy" command:
+
+    dest revert db/schema     # revert old action
+    dest deploy db/schema     # deploy new action
+    dest revdeploy db/schema  # revert old action and deploy new action
+
+=head2 Action with a Dependency
+
+Now let's create a data action, a Perl program that will do things and stuff
+to insert data into the database. To work, this action obviously will require
+the schema action to have already been deployed.
+
+    vi `dest make data/stuff pl`  # create the action and edit the files
+
+Inside the C<data/stuff/deploy.pl> file, include the following line:
+
+    # dest.prereq: db/schema
+
+Dependencies work in both deploy and revert files. Reverting the schema likely
+means dropping tables, so including a dependency to revert the data in those
+tables is probably just a waste of time. But if you really wanted to, you could
+optionally include in C<db/schema/revert.sql> the following line:
+
+    -- dest.prereq: data/stuff
+
+=head2 Other Developers
+
+Now let's say you invite a friend or coworker to the project. That person might
+do something like this:
+
+    git clone https://example.com/example_scenario project
+    cd project
+    dest init    # initiates dest and sets up watches from the watch file
+    dest update  # brings the local environment
+
+With the "update" command, C<dest> will notice that the "db/schema" and
+"data/stuff" actions haven't been deployed. It'll also notice that "data/stuff"
+depends on "db/schema", so it'll deploy the schema before it deploys the data.
+
+What's especially fun now is that this other developer can branch and do all
+sorts of work requiring C<dest> actions in parallel to you doing other C<dest>
+actions in parallel on different branches. If this new developer wants you to
+help test some changes, you just checkout the developer's branch and run a
+C<dest update>. C<dest> will revert whatever changes you have in your
+environment that don't exist in the other developer's environment, and will
+then deploy the other developer's new actions.
+
+    git checkout other_branch && dest update
+    prove t
+    git checkout my_branch && dest update
 
 =head1 SEE ALSO
 
